from setuptools import setup

setup(
    name='chess960',
    version='0.1.0',
    description='',
    url='http://github.com/qe/chess960',
    author='Alex Ismodes',
    author_email='helloemailmerighthere@gmail.com',
    license='MIT',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        'Topic :: Games/Entertainment :: Board Games'
    ],
    keywords='chess, chess960',
    packages=['chess960'],
    install_requires=[''],
    )
